==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkAbstractPolygonalHandleRepresentation3D.java <==
// java wrapper for vtkAbstractPolygonalHandleRepresentation3D object
//

package vtk;
import vtk.*;

public class vtkAbstractPolygonalHandleRepresentation3D extends vtkHandleRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWorldPosition_2(double id0[]);
  public void SetWorldPosition(double id0[])
    { SetWorldPosition_2(id0); }

  private native void SetDisplayPosition_3(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_3(id0); }

  private native void SetHandle_4(vtkPolyData id0);
  public void SetHandle(vtkPolyData id0)
    { SetHandle_4(id0); }

  private native long GetHandle_5();
  public vtkPolyData GetHandle() {
    long temp = GetHandle_5();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProperty_6(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_6(id0); }

  private native void SetSelectedProperty_7(vtkProperty id0);
  public void SetSelectedProperty(vtkProperty id0)
    { SetSelectedProperty_7(id0); }

  private native long GetProperty_8();
  public vtkProperty GetProperty() {
    long temp = GetProperty_8();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_9();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_9();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTransform_10();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_10();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_11();
  public void BuildRepresentation()
    { BuildRepresentation_11(); }

  private native void StartWidgetInteraction_12(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_12(id0); }

  private native void WidgetInteraction_13(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_13(id0); }

  private native int ComputeInteractionState_14(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_14(id0,id1,id2); }

  private native void ShallowCopy_15(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_15(id0); }

  private native void DeepCopy_16(vtkProp id0);
  public void DeepCopy(vtkProp id0)
    { DeepCopy_16(id0); }

  private native void GetActors_17(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_17(id0); }

  private native void ReleaseGraphicsResources_18(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_18(id0); }

  private native int RenderOpaqueGeometry_19(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_19(id0); }

  private native int RenderTranslucentPolygonalGeometry_20(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_20(id0); }

  private native int HasTranslucentPolygonalGeometry_21();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_21(); }

  private native void SetLabelVisibility_22(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_22(id0); }

  private native int GetLabelVisibility_23();
  public int GetLabelVisibility()
    { return GetLabelVisibility_23(); }

  private native void LabelVisibilityOn_24();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_24(); }

  private native void LabelVisibilityOff_25();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_25(); }

  private native void SetLabelText_26(String id0);
  public void SetLabelText(String id0)
    { SetLabelText_26(id0); }

  private native String GetLabelText_27();
  public String GetLabelText()
    { return GetLabelText_27(); }

  private native void SetLabelTextScale_28(double id0[]);
  public void SetLabelTextScale(double id0[])
    { SetLabelTextScale_28(id0); }

  private native void SetLabelTextScale_29(double id0,double id1,double id2);
  public void SetLabelTextScale(double id0,double id1,double id2)
    { SetLabelTextScale_29(id0,id1,id2); }

  private native long GetLabelTextActor_30();
  public vtkFollower GetLabelTextActor() {
    long temp = GetLabelTextActor_30();

    if (temp == 0) return null;
    return (vtkFollower)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUniformScale_31(double id0);
  public void SetUniformScale(double id0)
    { SetUniformScale_31(id0); }

  private native void SetHandleVisibility_32(int id0);
  public void SetHandleVisibility(int id0)
    { SetHandleVisibility_32(id0); }

  private native int GetHandleVisibility_33();
  public int GetHandleVisibility()
    { return GetHandleVisibility_33(); }

  private native void HandleVisibilityOn_34();
  public void HandleVisibilityOn()
    { HandleVisibilityOn_34(); }

  private native void HandleVisibilityOff_35();
  public void HandleVisibilityOff()
    { HandleVisibilityOff_35(); }

  private native void Highlight_36(int id0);
  public void Highlight(int id0)
    { Highlight_36(id0); }

  private native void SetSmoothMotion_37(int id0);
  public void SetSmoothMotion(int id0)
    { SetSmoothMotion_37(id0); }

  private native int GetSmoothMotion_38();
  public int GetSmoothMotion()
    { return GetSmoothMotion_38(); }

  private native void SmoothMotionOn_39();
  public void SmoothMotionOn()
    { SmoothMotionOn_39(); }

  private native void SmoothMotionOff_40();
  public void SmoothMotionOff()
    { SmoothMotionOff_40(); }

  public vtkAbstractPolygonalHandleRepresentation3D() { super(); }

  public vtkAbstractPolygonalHandleRepresentation3D(long id) { super(id); }

}

==> vtk-8.2.0-19-armv7h.pkg.tar.xz: vtk/vtkAbstractPolygonalHandleRepresentation3D.java <==
// java wrapper for vtkAbstractPolygonalHandleRepresentation3D object
//

package vtk;
import vtk.*;

public class vtkAbstractPolygonalHandleRepresentation3D extends vtkHandleRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWorldPosition_2(double id0[]);
  public void SetWorldPosition(double id0[])
    { SetWorldPosition_2(id0); }

  private native void SetDisplayPosition_3(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_3(id0); }

  private native void SetHandle_4(vtkPolyData id0);
  public void SetHandle(vtkPolyData id0)
    { SetHandle_4(id0); }

  private native long GetHandle_5();
  public vtkPolyData GetHandle() {
    long temp = GetHandle_5();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProperty_6(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_6(id0); }

  private native void SetSelectedProperty_7(vtkProperty id0);
  public void SetSelectedProperty(vtkProperty id0)
    { SetSelectedProperty_7(id0); }

  private native long GetProperty_8();
  public vtkProperty GetProperty() {
    long temp = GetProperty_8();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_9();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_9();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTransform_10();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_10();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_11();
  public void BuildRepresentation()
    { BuildRepresentation_11(); }

  private native void StartWidgetInteraction_12(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_12(id0); }

  private native void WidgetInteraction_13(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_13(id0); }

  private native int ComputeInteractionState_14(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_14(id0,id1,id2); }

  private native void ShallowCopy_15(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_15(id0); }

  private native void DeepCopy_16(vtkProp id0);
  public void DeepCopy(vtkProp id0)
    { DeepCopy_16(id0); }

  private native void GetActors_17(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_17(id0); }

  private native void ReleaseGraphicsResources_18(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_18(id0); }

  private native int RenderOpaqueGeometry_19(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_19(id0); }

  private native int RenderTranslucentPolygonalGeometry_20(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_20(id0); }

  private native int HasTranslucentPolygonalGeometry_21();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_21(); }

  private native void SetLabelVisibility_22(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_22(id0); }

  private native int GetLabelVisibility_23();
  public int GetLabelVisibility()
    { return GetLabelVisibility_23(); }

  private native void LabelVisibilityOn_24();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_24(); }

  private native void LabelVisibilityOff_25();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_25(); }

  private native void SetLabelText_26(String id0);
  public void SetLabelText(String id0)
    { SetLabelText_26(id0); }

  private native String GetLabelText_27();
  public String GetLabelText()
    { return GetLabelText_27(); }

  private native void SetLabelTextScale_28(double id0[]);
  public void SetLabelTextScale(double id0[])
    { SetLabelTextScale_28(id0); }

  private native void SetLabelTextScale_29(double id0,double id1,double id2);
  public void SetLabelTextScale(double id0,double id1,double id2)
    { SetLabelTextScale_29(id0,id1,id2); }

  private native long GetLabelTextActor_30();
  public vtkFollower GetLabelTextActor() {
    long temp = GetLabelTextActor_30();

    if (temp == 0) return null;
    return (vtkFollower)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUniformScale_31(double id0);
  public void SetUniformScale(double id0)
    { SetUniformScale_31(id0); }

  private native void SetHandleVisibility_32(int id0);
  public void SetHandleVisibility(int id0)
    { SetHandleVisibility_32(id0); }

  private native int GetHandleVisibility_33();
  public int GetHandleVisibility()
    { return GetHandleVisibility_33(); }

  private native void HandleVisibilityOn_34();
  public void HandleVisibilityOn()
    { HandleVisibilityOn_34(); }

  private native void HandleVisibilityOff_35();
  public void HandleVisibilityOff()
    { HandleVisibilityOff_35(); }

  private native void Highlight_36(int id0);
  public void Highlight(int id0)
    { Highlight_36(id0); }

  private native void SetSmoothMotion_37(int id0);
  public void SetSmoothMotion(int id0)
    { SetSmoothMotion_37(id0); }

  private native int GetSmoothMotion_38();
  public int GetSmoothMotion()
    { return GetSmoothMotion_38(); }

  private native void SmoothMotionOn_39();
  public void SmoothMotionOn()
    { SmoothMotionOn_39(); }

  private native void SmoothMotionOff_40();
  public void SmoothMotionOff()
    { SmoothMotionOff_40(); }

  private native void RegisterPickers_41();
  public void RegisterPickers()
    { RegisterPickers_41(); }

  public vtkAbstractPolygonalHandleRepresentation3D() { super(); }

  public vtkAbstractPolygonalHandleRepresentation3D(long id) { super(id); }

}
